@@ -17,9 +17,10 @@ try:
     dt, list_iso, it_title = sys.argv[1], sys.argv[2], sys.argv[3]
     name = dt[:dt.find('.txt')]
 except:
-    name = 'Pleiades_ruwe_cexcess_SelDist.txt'
-    list_iso = 'List_Iso21_PARSEC_GaiaEDR3.txt'
-    it_title = 'Pleiades'
+    url = 'https://github.com/sundarjhu/DAWGI_Lectures_2021/blob/main/Demo_DAWGI_HBM/Pleiades/'
+    name = url + 'Pleiades_ruwe_cexcess_SelDist.txt'
+    list_iso = url + 'List_Iso21_PARSEC_GaiaEDR3.txt'
+    it_title = url + 'Pleiades'
 
 #print('file: ', name)
 
